@@ -3,7 +3,8 @@ from .context.execution.execution import Execution
 from .context.session.session import Session
 from .context.user.user import User
 from .context.context.context import Context, root
-from .model.model import Model, poll, secs, mins, hours, days, months, dow, Init
+from .model import Model, poll, secs, mins, hours, days, months, dow, Init
 from .modifiers.state import private, public
 from .event import Event
-from .sdk import spiodirect
\ No newline at end of file
+from .sdk import spiodirect
+from .structs.table import Table
\ No newline at end of file
