@@ -1,6 +1,7 @@
 from datetime import datetime
 from typing import Any, Callable, Dict, List, Protocol, TypeVar, cast, Optional
 from .team import Stadiumlike
+from ...util.lru.lru import lru_cache_time
 
 import requests
 from dotenv import load_dotenv
@@ -130,7 +131,7 @@ class GameByDate(BaseModel):
     Stadium: Optional[Stadiumlike]
     Periods: List[Periodlike]
 
-
+@lru_cache_time(60, 32)
 def get_games(date : datetime) -> List[GameByDatelike]:
     """Gets games by date directly from sportsdataio
 
@@ -140,6 +141,7 @@ def get_games(date : datetime) -> List[GameByDatelike]:
     Returns:
         List[GameByDatelike]: are the games by date.
     """
+    print("READ THROUGH")
     domain = os.getenv("SPORTS_DATA_DOMAIN")
     json = requests.get(
         f"{domain}/v3/cbb/scores/json/GamesByDate/{date.year}-{date.month}-{date.day}",
