@@ -1,5 +1,6 @@
 from datetime import datetime
 from typing import Any, Callable, Dict, List, Protocol, TypeVar, cast, Optional
+from ...util.lru.lru import lru_cache_time
 
 import requests
 from dotenv import load_dotenv
@@ -117,6 +118,7 @@ class TeamSeasonStats(BaseModel):
     FantasyPointsDraftKings :  Optional[float]
     FantasyPointsYahoo :  Optional[float]
 
+lru_cache_time(60, 32)
 def get_team_season_stats_by_date(date : datetime) -> List[TeamSeasonStats]:
     """Gets games by date directly from sportsdataio
 
